/**
 * Common types, jQuery API, Form and Data controllers, utility functions.
 * @module data/common
 */
export type JQueryApi = JQuery<HTMLElement>;
/** Name of the jQuery data attribute used to store form controller */
export declare const SVELTE_FORM_STORE: string;
/** Determines how <InitComponent> is positioned related to the input to control */
export type ComponentInitMode = "parent" | "child" | "sibling";
/** How Init* components are looking for a Semantic UI input */
export declare function getComponentInitMode(): ComponentInitMode[];
/** Change component finding algorithm.
Setting to all modes will find component in any of the 3 locations.
Setting to empty array makes Init* component work only using forId param. */
export declare function setComponentInitMode(modes: ComponentInitMode[]): void;
/** Generate an unique number */
export declare function nextUid(): string;
/** Gets jQuery element by id attribute. */
export declare function jQueryElemById(id: string): JQueryApi;
/** Gets jQuery element by dom node. */
export declare function jQueryElem(node: Element): JQueryApi;
/** Find corresponding Semantic UI component,
where the `span` Element is a parent, child, or next sibling of the component.
Search mode is usually set in setComponentInitMode(), but may be overridden by `search` parameter. */
export declare function findComponent(span: Element, selector: string, id?: string, search?: ComponentInitMode[]): JQueryApi;
/** Get field identifier: id, name, data-validate */
export declare function getFieldKey(elem: JQueryApi): string | undefined;
/** Get or assign sequential field identifier: id, name, data-validate */
export declare function getOrAssignKey(elem: JQueryApi, prefix: string): string;
/** If the elem doesn't have key, copy parent field identifier: id, name, data-validate */
export declare function copyParentKey(elem: JQueryApi, parent: JQueryApi, prefix: string): string;
/** If the elem doesn't have key, copy parent field identifier: id, name, data-validate */
export declare function copyParentKeyIfExists(elem: JQueryApi, parent: JQueryApi, prefix: string): string | undefined;
/** Perform lookup for known parent types, copy parent id if it can. */
export declare function ensureFieldKey(elem: JQueryApi): string;
/** Search DOM tree for a parent form element  */
export declare function findParentForm(elem: JQueryApi): JQueryApi | undefined;
/** Find the label in the the same .ui.field with for="_" */
export declare function findLabelWithBlank(node: JQueryApi): JQueryApi | undefined;
